#
# Conditional build:
%bcond_without	tests		# build without tests
%bcond_without	static_libs	# don't build static libraries

%define		subver	2015-06-01
%define		ver		%(echo %{subver} | tr -d -)
Summary:	C++ fast alternative to backtracking RE engines
Name:		re2
Version:	%{ver}
Release:	1
License:	BSD
Group:		Libraries
Source0:	https://github.com/google/re2/archive/%{subver}/%{name}-%{version}.tar.gz
# Source0-md5:	9c3503091ed0ad1f1a8ac8ed72b440e9
Patch0:		test-compile.patch
URL:		https://github.com/google/re2
BuildRequires:	libstdc++-devel
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
RE2 is a C++ library providing a fast, safe, thread-friendly
alternative to backtracking regular expression engines like those used
in PCRE, Perl, and Python.

Backtracking engines are typically full of features and convenient
syntactic sugar but can be forced into taking exponential amounts of
time on even small inputs.

In contrast, RE2 uses automata theory to guarantee that regular
expression searches run in time linear in the size of the input, at
the expense of some missing features (e.g back references and
generalized assertions).

%package devel
Summary:	C++ header files and library symbolic links for %{name}
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
This package contains the C++ header files and symbolic links to the
shared libraries for %{name}. If you would like to develop programs
using %{name}, you will need to install %{name}-devel.

%package static
Summary:	Static %{name} library
Summary(pl.UTF-8):	Statyczna biblioteka %{name}
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static %{name} library.

%description static -l pl.UTF-8
Statyczna biblioteka %{name}.

%prep
%setup -q -n %{name}-%{subver}
%patch0 -p1

%build
# The -pthread flag issue has been submitted upstream:
# http://groups.google.com/forum/?fromgroups=#!topic/re2-dev/bkUDtO5l6Lo
%{__make} all %{?with_tests:compile-test} \
	CXX="%{__cxx}" \
	CXXFLAGS="%{rpmcxxflags}" \
	LDFLAGS="%{rpmldflags} -pthread" \
	includedir=%{_includedir} \
	libdir=%{_libdir}

%if %{with tests}
%{__make} test \
	CXX="%{__cxx}" \
	CXXFLAGS="%{rpmcxxflags}"
%endif

%install
rm -rf $RPM_BUILD_ROOT
%{__make} install \
	INSTALL="install -p" \
	includedir=%{_includedir} \
	libdir=%{_libdir} \
	DESTDIR=$RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS CONTRIBUTORS LICENSE README
%attr(755,root,root) %{_libdir}/libre2.so.*.*.*
%ghost %{_libdir}/libre2.so.0

%files devel
%defattr(644,root,root,755)
%doc doc/syntax.txt
%{_includedir}/re2
%{_libdir}/libre2.so
%{_pkgconfigdir}/re2.pc

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libre2.a
%endif
%changelog
* Mon Jun 08 2015 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/re2.git;a=log;h=master

* Sun Jun 07 2015 Elan Ruusamäe <glen@delfi.ee> dd936b8
- up to 2015-06-01. adds pkgconfig file, symbols patch is obsolete

* Sun Jun 07 2015 Elan Ruusamäe <glen@delfi.ee> 95478d9
- up to 20150501, new home in github

* Mon Mar 23 2015 Elan Ruusamäe <glen@delfi.ee> 2b5e65a
- x32 rebuild
- release 4 (by relup.sh)

* Mon Mar 23 2015 Elan Ruusamäe <glen@delfi.ee> 6ec7fca
- x32 rebuild
- release 3 (by relup.sh)

* Sat Mar 16 2013 Elan Ruusamäe <glen@delfi.ee> 9404520
- add  doc/syntax.txt to doc

* Sat Mar 16 2013 Elan Ruusamäe <glen@delfi.ee> e20d8a4
- export only specific symbol, matching more makes unit tests to abort

* Sat Mar 16 2013 Elan Ruusamäe <glen@delfi.ee> 7e0eb02
- export re2::FilteredRE2::* for chromium

* Sat Mar 16 2013 Elan Ruusamäe <glen@delfi.ee> e2543a2
- build test objects with main build

* Tue Feb 26 2013 Elan Ruusamäe <glen@delfi.ee> a64efc7
- BR: libstdc++-devel

* Tue Feb 26 2013 Elan Ruusamäe <glen@delfi.ee> 47fd5f8
- new, version 20130115

